/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvSignalBiquad.h"
#include "HvControlSystem.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlUnop.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_qhGNABIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3FiLQJXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sWSRt0Ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9179mRLT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dNV0Fjh0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_kHH1E9vX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vOMXHZlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zQmtR5YB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a97w3YIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pUV6PdVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nKgRbg7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pGAgQum8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WVDeqsTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dt3E6ALK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SrjVvXNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O6LYOiX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MvhvM6FH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1gr7AlYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HLUVYX9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_by7rZ9Me_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9PrzHdCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xk07ojSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_579KY922_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hXDds92Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gNgqiwHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bo1n5vMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7UKyZ1ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PYf4Wpmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8AbFi1u1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aHiX0Yp9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fNDQ7rmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_b4MUctzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ajtQ93YB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_upWDoD8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qdBoKCM9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hb0IPcSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FvweNATG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jEgoaONa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_foo56Fov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eLVQKiQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FoMMILB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I5Po5TLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cZDIxKdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9FUbPINS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kFTSNJgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CdCreFtU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WI3YNxYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RhNdCXIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pU5uzzWt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3lcnEbVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hpZAHHOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gme3ie8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rRVdljH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MIitWzz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ehzfcQ5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rJMsYADP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HW3tUEMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7HOM0QQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JbcmteHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0en2TaMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nsxuh9FT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ncNNvx0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZW46w3RO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CAjEvRYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4AMD5dLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2C2tw7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YVtkXLkd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HEplePNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mjapNxFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j5b008xN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxvxIrle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r6DhJCnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w9pKziuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OT1I7pGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TNAaWASQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ynxR55JD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PcQqNS4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_l5obNlmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_f2evRMJg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xaZVwjhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tXD8LvTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7bTGOvbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IS5M6AsU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_IGaL5Ofo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zRuoaZ4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sleXp9Xz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5sxedG52_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sDcxCJHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2s6zVuJb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ec4z7Lhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EziWMbyT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YCWEXxWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8TbCBq7i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_P1uYmin1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gn4QKeQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VELuWz5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p72uAoCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lqbH0VkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_woPWCg6f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FNkamWuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JtAcwcPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SC3W7pNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m2ndUoKW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CW8Vlu3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z8tpq8ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vr174ui3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6gD547Hn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iSwKt1nu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ORd3Gx0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ebCKaulR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xv8sgFYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ljFFU5cI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h1mb0x73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gkmyvk46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_72vqfQOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ecxCOWtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rdschpIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b0sWeJR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NeImPxRO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I8qlCjMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tfARwChJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IM5AaKFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_033iYqn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uhwdN1FS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3dWfCYSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SSkaZywK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6X31aCRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yfc34fsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yRoAWrbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cVYEktPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YUO506Ok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FJyXoN6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DLOpJpqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l5dNVz3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zNPXaqoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N2gAvd2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2uVopGFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z2aRtCfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O6qw4dtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3e5rXzc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KU27PBjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IUfK5lCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4LITggaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gVoEPJol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hczVUXw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9l5bnPHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JuuTOkAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dr9EceZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R0zh8tDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MDKo8DxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_maDgQmsq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cqqz5484_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lCkwOK4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TfUrYq4L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dykzIaZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wKmfuzLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BokV8TYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_y1VPcmvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9nRvh2YH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fh4umWRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yR9xtWUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_98qFMGHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GrlYN0wU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MJC2GK5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_op3WWeaU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9DlziKV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_039HinPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4e2y1uOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aGdod4k6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_thSqBbwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P7tOLzAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nrKXnUM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OvTA42WB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hy3d7QPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vwoh2q7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ujo1I6uG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ky1FEugh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LHNSxI3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rekUBaWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yeuJMPqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rCwZiduz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_r785JQ3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GzEWbO07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AE1sdfhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wKOEb51Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ml5pUEKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vWFOzzS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BpfIAWqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EH4z2hLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pdl7dCD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TTPeltzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XPy2t6jP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qHmCJgV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YQvLBuci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p90VNA4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yE23ABpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AVTpkGOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uUB84zei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lb56Qete_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3fwuuKax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aptJU4u7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5PDWp6VM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N6faCVAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0kfTy20c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k6KQxpT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wRPtsUHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_afnMZ2z9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r3Ph3QRG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eFipqedp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L1wru0zN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u3JPqnMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y12cMrIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gRQzKOk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_guZqjUzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uyMMVXiJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MEoDtAAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HlivIChL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yyZm0f7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJquktlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GOJKJE2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pf8B3Mj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N4yAZZP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kzf208zt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pEXE8tDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ncBeCTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bNA7eLYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uGTRWfef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V96lTWDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pussel5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sm8aMxjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tngKftDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XT3FnaQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YT9VGVUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lm6GsbPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Cjj5G0Is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cFLumcLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MjM5VPlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_j23Vu4I1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fDXqHrvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iXiR1RpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2NO9mUf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AwMjYnSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nevcuytJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_skJtIVEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_69qB2q9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lfKaUURm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M05cvBoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nOmRXn3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KlN4ypJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7aoL4AGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zUswEpTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BcMnV1Bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bwe6fDxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BUvAOmYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bdTfkyOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AWw06U8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ghkxgaC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fodl2IVu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xU9fSZ5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9XLy0E3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DCYg6Myj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Sd3sSc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cp0PKnca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vUGLgJoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ujYHiZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0WI0dM24_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xc1hEv6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Uz8SJkJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_W5kA0K47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ONlAi4Ou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RT5BbkTz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GQsYLblu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EP5dAIBc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bMTCuTQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YHIpcPoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZSME2C5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RbBUcFq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XtaxcDA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_86GsA0vg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SKd7S6vM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H42FVKDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KFaOgsh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aHHf3brG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FBXFEkKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GW9HDnbC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_prPOtdUZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RHe1pjds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wNQFYHtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZNl42d9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RNUy3nFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UL3TYZB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lj9JbExO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8KHOLavE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_b6uqQXnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gsS9RXmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z0lmg0yG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dEoRrSzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pAA3ltpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6FGVAho2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i9wz4MOl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sPfpgoEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PGUeUGuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bRtJBvv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vwUjd1Bs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pw9oIklt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eiz8vMcb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Otfu2Gvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kdt1MntY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ucjWzWl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wSlPhLEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3aqBpK9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WB9hFmbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ONEcsOtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Axnpq57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ei9dy345_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5pBKOO9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GsVPL0Hf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_i87avm1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CT7sVt2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mtm8sTmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LwjnulEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_igpMleVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SZ3VciG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_odUT2GsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbxJfT2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vO2lXG4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uxYNIDhW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aOeZE8Sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RLilui3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dvnGszcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9NW7O5D5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MpLChUNi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZAjSQtKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NPy2a4ld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MST1kEWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fjqSqH9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R8F1VBRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LCkSF330_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GTZMh7SA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Fuelhzbk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gtPdwDdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Wm0SNXxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ETYLNQTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PKZzwAkD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_W0aAyX9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CXrX7AU4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NBdTF5TI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fOrf8uI0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4F6CGifG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zAMTPvsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_42feBN0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9Qz15I8n_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LSkHn7p6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hOeb78DF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MY5FUT1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MxIpcuLx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GW91a5X5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PfiWSRgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vfbIdkiB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IFC343Cy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bLLEn5EX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eNui32Gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Zc3GGoZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mw8l3SVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hUVVirer_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BVJ1bvTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2lBt0gbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K3CDJGd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Wvb8CLd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_v9ziS4BP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ILBLEdrV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qb5zRN7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rwg5cJMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hTbKovjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rC9kwlJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SFzTQHaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7hHTziES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMzdTFUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ABe2dxAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K7I96gA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TwXvcpL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ET8OQzn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cNaBSSY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9mxfChtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SAruXKul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f2URHIfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p64lBeQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iPpg6H06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VHUKV6L7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7cd8SCnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VAb4OKbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AYEw8hZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UARNWrJE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O4JQFJgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nh0DCFtZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_akHQD1VS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jhjsYv6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_drIxQccg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1tKw2Zc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wmBjw55K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9CdA3PWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zE28I1bj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xce3pJM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i9kJyE5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g3vcggFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gAv47LSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2X68rkj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zT6E2HHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q3xd8myH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oBO4UPy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HT51qJGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cDNudvQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xqPdmRdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_epmv7p1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fh1aLuHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4U8cjr5v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dpYFig24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JEkxqMo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7Ae4pyWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3xcwTLiw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZHoyXoGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QTrgx3GD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PgvPysQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FszjIknT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FUGYJQUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5AbFweVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_13Va9DD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2BTrvdoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0zkBfVl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oYySgIe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DRQrytp9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pDwxNnnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TDc2eNv8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lgBq5lXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2rqxU30c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GSnMlE5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ix1uXTNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0gSv4WIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_erxDMBKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EvbnT76C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UhEXpQHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pf3nlJYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sbiYWidd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Eruv4DUg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YAOD1DUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zeXXSTbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sUbIPOxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zZRVvfQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tQcgyrJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B2b6WUyR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0L0akxop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vzzz6NRT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ecSZeBkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R2tcJwCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fvGBHevo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V4z9Y6iA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hjqcIlsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HEg9CWS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zib3Gkq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W6AzdvGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rrpFwIiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7G9ZqHC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BfP0atDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J2O15mBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_euhHHfIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mnmb8E3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iEdk6zqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m8IA0LZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Jes4dqBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TDPWpd4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vk3PY6yC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5QQZ8iBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZWChMUg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_enkhrVY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PdJGNjup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qogrlsV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SL4HITQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r2EmusFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ke42Xfyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qrrEExjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vcSJxknM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6LkqnIrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XTdGHaB4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JnpmaF2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sQBgCqvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JiYaMTyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EVYUWR0M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u9Kb7nDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UPJpPeoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m6P0ORxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xRdvo4oU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VUVevOPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1ef8aTuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ijlGUrNi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lFMLigsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0KYTh826_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PMKCfwML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VNx4ybcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_K7KRRkb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0gkMoN3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7x1wLEsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CCYoZtn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hA4UTIKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IzgNYbws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_meJRR334_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5KEpUVLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wBrrSpWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WaVg4eTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ooCAz8Cp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FjZrFvv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gJqQKZ31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_al2qBViA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OKzc8GMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yvaLNrdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ew07y0RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XKpJJ0OT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_42wDLq1x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xUrxiFCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T3MBqz2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TVUEPxeF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1hQ0ZwZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pXFAuZnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dIwqDxO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nypf8UDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MQMOLiFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oQxpCLCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dDkYZ3p6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sph1nIaU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jkcOavng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gde3Jq1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pMWhM2yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2peKLijJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fXuqk1L3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uJXiQNfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rFhsUKnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0FtrjENw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xB3uJOyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9IjZNcKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2rDZV42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3nsPdcvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hpjEZrnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S4D23eA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ZEfxxdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9eTyoPw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CrCqOLw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kt9Rhbjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_66ectCZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oQNXWpy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qAA6OGrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VEu6CuHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x13twqip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pC08Igqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9OSrPYjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ISiI3bbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1kVyjuOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gFbfCEZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ezKJD4wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_epJTOwpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BFvh9tQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4Vr5BuAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_16oiUCye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U1C9aDwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NXzTrIWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rCKYa1wq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lgo5iZQJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HM9HNkvx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gJwZW3iE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6vlFIjDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_51G6GvlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T0oPiE4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6nz8HwMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9aGfyf4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rPAsSl97_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IwkbYP7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lWuIRsSv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fyDWDISa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gre0t0PD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_f1FQ97Nq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8OJzxXlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ihQ9V0Fq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_z6bxYSBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_iP6yz6CU;
  SignalLine sLine_8OnvMezE;
  SignalLine sLine_cdQmqmFo;
  SignalLine sLine_ijiHDqQI;
  SignalLine sLine_xWB5X9IX;
  SignalBiquad sBiquad_s_2nfkrUx2;
  SignalLine sLine_HzWAWCWw;
  SignalLine sLine_oTo8SFxu;
  SignalLine sLine_XI1rMwky;
  SignalLine sLine_EdX5kXCM;
  SignalBiquad sBiquad_s_KQpCi64x;
  SignalLine sLine_0kKQUjss;
  SignalLine sLine_NUMDYUB1;
  SignalLine sLine_t8aUU01Q;
  SignalLine sLine_oKGddUhG;
  SignalLine sLine_nWukp65t;
  SignalBiquad sBiquad_s_pXkl1OUz;
  SignalLine sLine_SXIYZcOU;
  SignalLine sLine_CW4pAlgA;
  SignalLine sLine_j83FWTJF;
  SignalLine sLine_lW79zaPq;
  SignalLine sLine_82MiiZWy;
  SignalBiquad sBiquad_s_kfT5o06C;
  SignalLine sLine_RxHQYPWS;
  SignalLine sLine_MGkfFXxB;
  SignalLine sLine_hfJjCx0B;
  SignalLine sLine_SF1XYWhJ;
  SignalBiquad sBiquad_s_tJmKGh0Z;
  SignalLine sLine_hKv7R6RQ;
  SignalLine sLine_UIaLReIg;
  SignalLine sLine_VUl86IV5;
  SignalLine sLine_pefKNPHT;
  SignalLine sLine_M3uYUFF8;
  SignalBiquad sBiquad_s_BJaeHudG;
  ControlVar cVar_qhGNABIr;
  ControlVar cVar_3FiLQJXT;
  ControlVar cVar_sWSRt0Ct;
  ControlVar cVar_9179mRLT;
  ControlSlice cSlice_kHH1E9vX;
  ControlVar cVar_vOMXHZlR;
  ControlVar cVar_a97w3YIn;
  ControlIf cIf_pUV6PdVk;
  ControlIf cIf_nKgRbg7V;
  ControlBinop cBinop_WVDeqsTt;
  ControlBinop cBinop_Dt3E6ALK;
  ControlBinop cBinop_MvhvM6FH;
  ControlBinop cBinop_1gr7AlYL;
  ControlBinop cBinop_by7rZ9Me;
  ControlIf cIf_9PrzHdCr;
  ControlBinop cBinop_xk07ojSC;
  ControlBinop cBinop_579KY922;
  ControlBinop cBinop_gNgqiwHp;
  ControlBinop cBinop_bo1n5vMk;
  ControlBinop cBinop_7UKyZ1ny;
  ControlVar cVar_b4MUctzZ;
  ControlIf cIf_ajtQ93YB;
  ControlIf cIf_upWDoD8D;
  ControlBinop cBinop_Hb0IPcSV;
  ControlBinop cBinop_FvweNATG;
  ControlBinop cBinop_eLVQKiQY;
  ControlBinop cBinop_FoMMILB8;
  ControlBinop cBinop_cZDIxKdf;
  ControlIf cIf_9FUbPINS;
  ControlBinop cBinop_kFTSNJgt;
  ControlBinop cBinop_CdCreFtU;
  ControlBinop cBinop_RhNdCXIy;
  ControlBinop cBinop_pU5uzzWt;
  ControlBinop cBinop_3lcnEbVJ;
  ControlVar cVar_ehzfcQ5C;
  ControlIf cIf_rJMsYADP;
  ControlIf cIf_HW3tUEMc;
  ControlBinop cBinop_JbcmteHL;
  ControlBinop cBinop_0en2TaMA;
  ControlBinop cBinop_ZW46w3RO;
  ControlBinop cBinop_CAjEvRYx;
  ControlBinop cBinop_O2C2tw7j;
  ControlIf cIf_YVtkXLkd;
  ControlBinop cBinop_HEplePNE;
  ControlBinop cBinop_mjapNxFy;
  ControlBinop cBinop_qxvxIrle;
  ControlBinop cBinop_r6DhJCnC;
  ControlBinop cBinop_w9pKziuE;
  ControlIf cIf_l5obNlmR;
  ControlSlice cSlice_xaZVwjhF;
  ControlVar cVar_tXD8LvTj;
  ControlSlice cSlice_IGaL5Ofo;
  ControlVar cVar_zRuoaZ4W;
  ControlSlice cSlice_sDcxCJHd;
  ControlVar cVar_2s6zVuJb;
  ControlSlice cSlice_YCWEXxWM;
  ControlVar cVar_8TbCBq7i;
  ControlBinop cBinop_CW8Vlu3g;
  ControlBinop cBinop_Vr174ui3;
  ControlBinop cBinop_6gD547Hn;
  ControlBinop cBinop_ebCKaulR;
  ControlBinop cBinop_xv8sgFYc;
  ControlBinop cBinop_ljFFU5cI;
  ControlBinop cBinop_h1mb0x73;
  ControlBinop cBinop_Gkmyvk46;
  ControlVar cVar_72vqfQOq;
  ControlBinop cBinop_ecxCOWtL;
  ControlBinop cBinop_rdschpIy;
  ControlBinop cBinop_b0sWeJR4;
  ControlBinop cBinop_NeImPxRO;
  ControlBinop cBinop_I8qlCjMx;
  ControlBinop cBinop_tfARwChJ;
  ControlBinop cBinop_IM5AaKFM;
  ControlBinop cBinop_uhwdN1FS;
  ControlVar cVar_3dWfCYSA;
  ControlVar cVar_SSkaZywK;
  ControlBinop cBinop_DLOpJpqy;
  ControlBinop cBinop_l5dNVz3f;
  ControlBinop cBinop_zNPXaqoJ;
  ControlBinop cBinop_2uVopGFt;
  ControlBinop cBinop_Z2aRtCfH;
  ControlBinop cBinop_O6qw4dtH;
  ControlBinop cBinop_3e5rXzc3;
  ControlBinop cBinop_KU27PBjY;
  ControlBinop cBinop_IUfK5lCN;
  ControlBinop cBinop_yR9xtWUr;
  ControlBinop cBinop_GrlYN0wU;
  ControlBinop cBinop_MJC2GK5k;
  ControlBinop cBinop_039HinPL;
  ControlBinop cBinop_4e2y1uOd;
  ControlBinop cBinop_aGdod4k6;
  ControlBinop cBinop_thSqBbwY;
  ControlBinop cBinop_P7tOLzAL;
  ControlBinop cBinop_nrKXnUM6;
  ControlBinop cBinop_OvTA42WB;
  ControlBinop cBinop_vwoh2q7j;
  ControlVar cVar_ujo1I6uG;
  ControlVar cVar_ky1FEugh;
  ControlVar cVar_LHNSxI3A;
  ControlBinop cBinop_wKOEb51Z;
  ControlBinop cBinop_ml5pUEKn;
  ControlBinop cBinop_vWFOzzS9;
  ControlBinop cBinop_EH4z2hLH;
  ControlBinop cBinop_pdl7dCD5;
  ControlBinop cBinop_TTPeltzL;
  ControlBinop cBinop_XPy2t6jP;
  ControlBinop cBinop_qHmCJgV5;
  ControlBinop cBinop_u3JPqnMf;
  ControlBinop cBinop_gRQzKOk6;
  ControlBinop cBinop_guZqjUzz;
  ControlBinop cBinop_HlivIChL;
  ControlBinop cBinop_yyZm0f7U;
  ControlBinop cBinop_sJquktlg;
  ControlBinop cBinop_GOJKJE2X;
  ControlBinop cBinop_pf8B3Mj9;
  ControlBinop cBinop_kzf208zt;
  ControlBinop cBinop_7ncBeCTi;
  ControlBinop cBinop_bNA7eLYS;
  ControlBinop cBinop_V96lTWDz;
  ControlBinop cBinop_pussel5W;
  ControlBinop cBinop_Sm8aMxjL;
  ControlBinop cBinop_XT3FnaQB;
  ControlVar cVar_YT9VGVUi;
  ControlVar cVar_lm6GsbPy;
  ControlVar cVar_Cjj5G0Is;
  ControlBinop cBinop_AwMjYnSO;
  ControlBinop cBinop_nevcuytJ;
  ControlBinop cBinop_skJtIVEe;
  ControlBinop cBinop_lfKaUURm;
  ControlBinop cBinop_M05cvBoY;
  ControlBinop cBinop_nOmRXn3K;
  ControlBinop cBinop_KlN4ypJZ;
  ControlBinop cBinop_7aoL4AGu;
  ControlBinop cBinop_zUswEpTM;
  ControlBinop cBinop_5Sd3sSc3;
  ControlBinop cBinop_vUGLgJoo;
  ControlBinop cBinop_8ujYHiZY;
  SignalVarf sVarf_kr9YhYER;
  SignalVarf sVarf_tOsnwONB;
  SignalVarf sVarf_4GEok2s3;
  ControlSlice cSlice_xc1hEv6Y;
  ControlVar cVar_Uz8SJkJB;
  ControlVar cVar_ONlAi4Ou;
  ControlIf cIf_RT5BbkTz;
  ControlIf cIf_GQsYLblu;
  ControlBinop cBinop_bMTCuTQW;
  ControlBinop cBinop_YHIpcPoC;
  ControlBinop cBinop_XtaxcDA1;
  ControlBinop cBinop_86GsA0vg;
  ControlBinop cBinop_H42FVKDE;
  ControlIf cIf_KFaOgsh7;
  ControlBinop cBinop_aHHf3brG;
  ControlBinop cBinop_FBXFEkKc;
  ControlBinop cBinop_prPOtdUZ;
  ControlBinop cBinop_RHe1pjds;
  ControlBinop cBinop_wNQFYHtS;
  ControlVar cVar_8KHOLavE;
  ControlIf cIf_b6uqQXnz;
  ControlIf cIf_gsS9RXmD;
  ControlBinop cBinop_dEoRrSzS;
  ControlBinop cBinop_pAA3ltpG;
  ControlBinop cBinop_sPfpgoEj;
  ControlBinop cBinop_PGUeUGuj;
  ControlBinop cBinop_vwUjd1Bs;
  ControlIf cIf_pw9oIklt;
  ControlBinop cBinop_Eiz8vMcb;
  ControlBinop cBinop_Otfu2Gvq;
  ControlBinop cBinop_ucjWzWl9;
  ControlBinop cBinop_wSlPhLEp;
  ControlBinop cBinop_3aqBpK9z;
  ControlVar cVar_5pBKOO9U;
  ControlIf cIf_GsVPL0Hf;
  ControlIf cIf_i87avm1P;
  ControlBinop cBinop_Mtm8sTmI;
  ControlBinop cBinop_LwjnulEk;
  ControlBinop cBinop_odUT2GsN;
  ControlBinop cBinop_gbxJfT2R;
  ControlBinop cBinop_uxYNIDhW;
  ControlIf cIf_aOeZE8Sp;
  ControlBinop cBinop_RLilui3r;
  ControlBinop cBinop_dvnGszcG;
  ControlBinop cBinop_MpLChUNi;
  ControlBinop cBinop_ZAjSQtKV;
  ControlBinop cBinop_NPy2a4ld;
  ControlIf cIf_GTZMh7SA;
  ControlSlice cSlice_gtPdwDdn;
  ControlVar cVar_Wm0SNXxJ;
  ControlSlice cSlice_W0aAyX9R;
  ControlVar cVar_CXrX7AU4;
  ControlSlice cSlice_4F6CGifG;
  ControlVar cVar_zAMTPvsX;
  ControlSlice cSlice_LSkHn7p6;
  ControlVar cVar_hOeb78DF;
  ControlBinop cBinop_hUVVirer;
  ControlBinop cBinop_2lBt0gbX;
  ControlBinop cBinop_K3CDJGd4;
  ControlBinop cBinop_ILBLEdrV;
  ControlBinop cBinop_Qb5zRN7f;
  ControlBinop cBinop_rwg5cJMJ;
  ControlBinop cBinop_hTbKovjy;
  ControlBinop cBinop_rC9kwlJF;
  ControlVar cVar_SFzTQHaj;
  ControlBinop cBinop_7hHTziES;
  ControlBinop cBinop_yMzdTFUj;
  ControlBinop cBinop_ABe2dxAS;
  ControlBinop cBinop_K7I96gA4;
  ControlBinop cBinop_TwXvcpL2;
  ControlBinop cBinop_9ET8OQzn;
  ControlBinop cBinop_cNaBSSY3;
  ControlBinop cBinop_SAruXKul;
  ControlVar cVar_f2URHIfG;
  ControlVar cVar_p64lBeQs;
  ControlBinop cBinop_O4JQFJgI;
  ControlBinop cBinop_nh0DCFtZ;
  ControlBinop cBinop_akHQD1VS;
  ControlBinop cBinop_drIxQccg;
  ControlBinop cBinop_1tKw2Zc7;
  ControlBinop cBinop_wmBjw55K;
  ControlBinop cBinop_9CdA3PWY;
  ControlBinop cBinop_zE28I1bj;
  ControlBinop cBinop_Xce3pJM8;
  ControlBinop cBinop_QTrgx3GD;
  ControlBinop cBinop_FszjIknT;
  ControlBinop cBinop_FUGYJQUG;
  ControlBinop cBinop_2BTrvdoH;
  ControlBinop cBinop_0zkBfVl5;
  ControlBinop cBinop_oYySgIe9;
  ControlBinop cBinop_DRQrytp9;
  ControlBinop cBinop_pDwxNnnJ;
  ControlBinop cBinop_TDc2eNv8;
  ControlBinop cBinop_lgBq5lXJ;
  ControlBinop cBinop_GSnMlE5O;
  ControlVar cVar_ix1uXTNJ;
  ControlVar cVar_0gSv4WIY;
  ControlVar cVar_erxDMBKN;
  ControlBinop cBinop_zeXXSTbI;
  ControlBinop cBinop_sUbIPOxQ;
  ControlBinop cBinop_zZRVvfQ2;
  ControlBinop cBinop_B2b6WUyR;
  ControlBinop cBinop_0L0akxop;
  ControlBinop cBinop_vzzz6NRT;
  ControlBinop cBinop_ecSZeBkx;
  ControlBinop cBinop_R2tcJwCQ;
  ControlBinop cBinop_5QQZ8iBD;
  ControlBinop cBinop_enkhrVY1;
  ControlBinop cBinop_PdJGNjup;
  ControlBinop cBinop_r2EmusFc;
  ControlBinop cBinop_Ke42Xfyp;
  ControlBinop cBinop_qrrEExjV;
  ControlBinop cBinop_vcSJxknM;
  ControlBinop cBinop_6LkqnIrs;
  ControlBinop cBinop_JnpmaF2Q;
  ControlBinop cBinop_JiYaMTyC;
  ControlBinop cBinop_EVYUWR0M;
  ControlBinop cBinop_UPJpPeoi;
  ControlBinop cBinop_m6P0ORxY;
  ControlBinop cBinop_xRdvo4oU;
  ControlBinop cBinop_1ef8aTuz;
  ControlVar cVar_ijlGUrNi;
  ControlVar cVar_lFMLigsH;
  ControlVar cVar_0KYTh826;
  ControlBinop cBinop_hA4UTIKX;
  ControlBinop cBinop_IzgNYbws;
  ControlBinop cBinop_meJRR334;
  ControlBinop cBinop_wBrrSpWe;
  ControlBinop cBinop_WaVg4eTy;
  ControlBinop cBinop_ooCAz8Cp;
  ControlBinop cBinop_FjZrFvv3;
  ControlBinop cBinop_gJqQKZ31;
  ControlBinop cBinop_al2qBViA;
  ControlBinop cBinop_dIwqDxO3;
  ControlBinop cBinop_MQMOLiFv;
  ControlBinop cBinop_oQxpCLCK;
  SignalVarf sVarf_CFvQd8CY;
  SignalVarf sVarf_xdvl9hUn;
  SignalVarf sVarf_tRB4Txqn;
  SignalVarf sVarf_sxFw4p9O;
  SignalVarf sVarf_LRM9HkEV;
  SignalVarf sVarf_3LPTPrnm;
  SignalVarf sVarf_oVGDfpux;
  SignalVarf sVarf_HBdbFLjY;
  SignalVarf sVarf_SUFj5CV9;
  ControlVar cVar_dDkYZ3p6;
  ControlVar cVar_sph1nIaU;
  ControlBinop cBinop_uJXiQNfa;
  ControlBinop cBinop_rFhsUKnw;
  ControlBinop cBinop_0FtrjENw;
  ControlBinop cBinop_9IjZNcKr;
  ControlBinop cBinop_e2rDZV42;
  ControlBinop cBinop_3nsPdcvs;
  ControlBinop cBinop_hpjEZrnJ;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
