/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_iP6yz6CU);
  numBytes += sLine_init(&sLine_8OnvMezE);
  numBytes += sLine_init(&sLine_cdQmqmFo);
  numBytes += sLine_init(&sLine_ijiHDqQI);
  numBytes += sLine_init(&sLine_xWB5X9IX);
  numBytes += sBiquad_init(&sBiquad_s_2nfkrUx2);
  numBytes += sLine_init(&sLine_HzWAWCWw);
  numBytes += sLine_init(&sLine_oTo8SFxu);
  numBytes += sLine_init(&sLine_XI1rMwky);
  numBytes += sLine_init(&sLine_EdX5kXCM);
  numBytes += sBiquad_init(&sBiquad_s_KQpCi64x);
  numBytes += sLine_init(&sLine_0kKQUjss);
  numBytes += sLine_init(&sLine_NUMDYUB1);
  numBytes += sLine_init(&sLine_t8aUU01Q);
  numBytes += sLine_init(&sLine_oKGddUhG);
  numBytes += sLine_init(&sLine_nWukp65t);
  numBytes += sBiquad_init(&sBiquad_s_pXkl1OUz);
  numBytes += sLine_init(&sLine_SXIYZcOU);
  numBytes += sLine_init(&sLine_CW4pAlgA);
  numBytes += sLine_init(&sLine_j83FWTJF);
  numBytes += sLine_init(&sLine_lW79zaPq);
  numBytes += sLine_init(&sLine_82MiiZWy);
  numBytes += sBiquad_init(&sBiquad_s_kfT5o06C);
  numBytes += sLine_init(&sLine_RxHQYPWS);
  numBytes += sLine_init(&sLine_MGkfFXxB);
  numBytes += sLine_init(&sLine_hfJjCx0B);
  numBytes += sLine_init(&sLine_SF1XYWhJ);
  numBytes += sBiquad_init(&sBiquad_s_tJmKGh0Z);
  numBytes += sLine_init(&sLine_hKv7R6RQ);
  numBytes += sLine_init(&sLine_UIaLReIg);
  numBytes += sLine_init(&sLine_VUl86IV5);
  numBytes += sLine_init(&sLine_pefKNPHT);
  numBytes += sLine_init(&sLine_M3uYUFF8);
  numBytes += sBiquad_init(&sBiquad_s_BJaeHudG);
  numBytes += cVar_init_f(&cVar_qhGNABIr, 0.0f);
  numBytes += cVar_init_f(&cVar_3FiLQJXT, 0.0f);
  numBytes += cVar_init_f(&cVar_sWSRt0Ct, 0.0f);
  numBytes += cVar_init_f(&cVar_9179mRLT, 0.0f);
  numBytes += cSlice_init(&cSlice_kHH1E9vX, 1, -1);
  numBytes += cVar_init_f(&cVar_vOMXHZlR, 1337.0f);
  numBytes += cVar_init_f(&cVar_a97w3YIn, 0.0f);
  numBytes += cIf_init(&cIf_pUV6PdVk, false);
  numBytes += cIf_init(&cIf_nKgRbg7V, false);
  numBytes += cBinop_init(&cBinop_WVDeqsTt, 0.0f); // __pow
  numBytes += cIf_init(&cIf_9PrzHdCr, false);
  numBytes += cBinop_init(&cBinop_gNgqiwHp, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bo1n5vMk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7UKyZ1ny, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_b4MUctzZ, 0.0f);
  numBytes += cIf_init(&cIf_ajtQ93YB, false);
  numBytes += cIf_init(&cIf_upWDoD8D, false);
  numBytes += cBinop_init(&cBinop_Hb0IPcSV, 0.0f); // __pow
  numBytes += cIf_init(&cIf_9FUbPINS, false);
  numBytes += cBinop_init(&cBinop_RhNdCXIy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_pU5uzzWt, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3lcnEbVJ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ehzfcQ5C, 0.0f);
  numBytes += cIf_init(&cIf_rJMsYADP, false);
  numBytes += cIf_init(&cIf_HW3tUEMc, false);
  numBytes += cBinop_init(&cBinop_JbcmteHL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YVtkXLkd, false);
  numBytes += cBinop_init(&cBinop_qxvxIrle, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_r6DhJCnC, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_w9pKziuE, -15.0f); // __eq
  numBytes += cIf_init(&cIf_l5obNlmR, false);
  numBytes += cSlice_init(&cSlice_xaZVwjhF, 1, -1);
  numBytes += cVar_init_f(&cVar_tXD8LvTj, 0.0f);
  numBytes += cSlice_init(&cSlice_IGaL5Ofo, 1, -1);
  numBytes += cVar_init_f(&cVar_zRuoaZ4W, 0.0f);
  numBytes += cSlice_init(&cSlice_sDcxCJHd, 1, -1);
  numBytes += cVar_init_f(&cVar_2s6zVuJb, 0.0f);
  numBytes += cSlice_init(&cSlice_YCWEXxWM, 1, -1);
  numBytes += cVar_init_f(&cVar_8TbCBq7i, 0.313f);
  numBytes += cBinop_init(&cBinop_Vr174ui3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_6gD547Hn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_72vqfQOq, 0.0f);
  numBytes += cVar_init_f(&cVar_3dWfCYSA, 1337.0f);
  numBytes += cVar_init_f(&cVar_SSkaZywK, 0.3f);
  numBytes += cBinop_init(&cBinop_l5dNVz3f, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z2aRtCfH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_O6qw4dtH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3e5rXzc3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KU27PBjY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IUfK5lCN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GrlYN0wU, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MJC2GK5k, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ujo1I6uG, 0.0f);
  numBytes += cVar_init_f(&cVar_ky1FEugh, 1337.0f);
  numBytes += cVar_init_f(&cVar_LHNSxI3A, 0.313f);
  numBytes += cBinop_init(&cBinop_ml5pUEKn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pdl7dCD5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TTPeltzL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XPy2t6jP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qHmCJgV5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gRQzKOk6, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_guZqjUzz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YT9VGVUi, 0.0f);
  numBytes += cVar_init_f(&cVar_lm6GsbPy, 1037.0f);
  numBytes += cVar_init_f(&cVar_Cjj5G0Is, 0.4f);
  numBytes += cBinop_init(&cBinop_nevcuytJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M05cvBoY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nOmRXn3K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KlN4ypJZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7aoL4AGu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zUswEpTM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kr9YhYER, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tOsnwONB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4GEok2s3, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_xc1hEv6Y, 1, -1);
  numBytes += cVar_init_f(&cVar_Uz8SJkJB, 1337.0f);
  numBytes += cVar_init_f(&cVar_ONlAi4Ou, 0.0f);
  numBytes += cIf_init(&cIf_RT5BbkTz, false);
  numBytes += cIf_init(&cIf_GQsYLblu, false);
  numBytes += cBinop_init(&cBinop_bMTCuTQW, 0.0f); // __pow
  numBytes += cIf_init(&cIf_KFaOgsh7, false);
  numBytes += cBinop_init(&cBinop_prPOtdUZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_RHe1pjds, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wNQFYHtS, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_8KHOLavE, 0.0f);
  numBytes += cIf_init(&cIf_b6uqQXnz, false);
  numBytes += cIf_init(&cIf_gsS9RXmD, false);
  numBytes += cBinop_init(&cBinop_dEoRrSzS, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pw9oIklt, false);
  numBytes += cBinop_init(&cBinop_ucjWzWl9, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wSlPhLEp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3aqBpK9z, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5pBKOO9U, 0.0f);
  numBytes += cIf_init(&cIf_GsVPL0Hf, false);
  numBytes += cIf_init(&cIf_i87avm1P, false);
  numBytes += cBinop_init(&cBinop_Mtm8sTmI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aOeZE8Sp, false);
  numBytes += cBinop_init(&cBinop_MpLChUNi, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZAjSQtKV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NPy2a4ld, -15.0f); // __eq
  numBytes += cIf_init(&cIf_GTZMh7SA, false);
  numBytes += cSlice_init(&cSlice_gtPdwDdn, 1, -1);
  numBytes += cVar_init_f(&cVar_Wm0SNXxJ, 0.0f);
  numBytes += cSlice_init(&cSlice_W0aAyX9R, 1, -1);
  numBytes += cVar_init_f(&cVar_CXrX7AU4, 0.0f);
  numBytes += cSlice_init(&cSlice_4F6CGifG, 1, -1);
  numBytes += cVar_init_f(&cVar_zAMTPvsX, 0.0f);
  numBytes += cSlice_init(&cSlice_LSkHn7p6, 1, -1);
  numBytes += cVar_init_f(&cVar_hOeb78DF, 0.313f);
  numBytes += cBinop_init(&cBinop_2lBt0gbX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_K3CDJGd4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SFzTQHaj, 0.0f);
  numBytes += cVar_init_f(&cVar_f2URHIfG, 1337.0f);
  numBytes += cVar_init_f(&cVar_p64lBeQs, 0.3f);
  numBytes += cBinop_init(&cBinop_nh0DCFtZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1tKw2Zc7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wmBjw55K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9CdA3PWY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zE28I1bj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Xce3pJM8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FszjIknT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FUGYJQUG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ix1uXTNJ, 0.0f);
  numBytes += cVar_init_f(&cVar_0gSv4WIY, 1337.0f);
  numBytes += cVar_init_f(&cVar_erxDMBKN, 0.313f);
  numBytes += cBinop_init(&cBinop_sUbIPOxQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0L0akxop, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vzzz6NRT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ecSZeBkx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R2tcJwCQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_enkhrVY1, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PdJGNjup, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ijlGUrNi, 0.0f);
  numBytes += cVar_init_f(&cVar_lFMLigsH, 1037.0f);
  numBytes += cVar_init_f(&cVar_0KYTh826, 0.4f);
  numBytes += cBinop_init(&cBinop_IzgNYbws, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WaVg4eTy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ooCAz8Cp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FjZrFvv3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gJqQKZ31, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_al2qBViA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CFvQd8CY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xdvl9hUn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tRB4Txqn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sxFw4p9O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LRM9HkEV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3LPTPrnm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oVGDfpux, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HBdbFLjY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SUFj5CV9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dDkYZ3p6, 5705.6f);
  numBytes += cVar_init_f(&cVar_sph1nIaU, 313.3f);
  numBytes += cBinop_init(&cBinop_uJXiQNfa, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_rFhsUKnw, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_0FtrjENw, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qAA6OGrr_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x13twqip_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VEu6CuHu_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z6bxYSBf_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ISiI3bbp_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1kVyjuOi_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pC08Igqc_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9OSrPYjC_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gFbfCEZG_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4Vr5BuAT_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BFvh9tQX_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_epJTOwpi_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NXzTrIWh_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U1C9aDwc_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_16oiUCye_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HM9HNkvx_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lgo5iZQJ_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rCKYa1wq_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_51G6GvlG_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T0oPiE4u_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gJwZW3iE_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6vlFIjDp_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6nz8HwMj_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IwkbYP7S_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rPAsSl97_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9aGfyf4q_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gre0t0PD_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fyDWDISa_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lWuIRsSv_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ihQ9V0Fq_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8OJzxXlp_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f1FQ97Nq_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ezKJD4wy_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_qhGNABIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S4D23eA1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_3FiLQJXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ZEfxxdk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_sWSRt0Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9eTyoPw6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_9179mRLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CrCqOLw5_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fXuqk1L3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2peKLijJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pMWhM2yw_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_dNV0Fjh0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kHH1E9vX, 0, m, &cSlice_kHH1E9vX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5sxedG52_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_kHH1E9vX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zQmtR5YB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zQmtR5YB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vOMXHZlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zQmtR5YB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_zQmtR5YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pC08Igqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_a97w3YIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xk07ojSC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_pUV6PdVk, 0, m, &cIf_pUV6PdVk_sendMessage);
}

void Heavy_WSTD_EQ::cIf_pUV6PdVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_579KY922_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_nKgRbg7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HLUVYX9V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1gr7AlYL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_pGAgQum8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WVDeqsTt, HV_BINOP_POW, 0, m, &cBinop_WVDeqsTt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WVDeqsTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9PrzHdCr, 0, m, &cIf_9PrzHdCr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Dt3E6ALK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_by7rZ9Me_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SrjVvXNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MvhvM6FH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O6LYOiX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nKgRbg7V, 0, m, &cIf_nKgRbg7V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MvhvM6FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nKgRbg7V, 1, m, &cIf_nKgRbg7V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1gr7AlYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Dt3E6ALK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HLUVYX9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9PrzHdCr, 0, m, &cIf_9PrzHdCr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_by7rZ9Me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WVDeqsTt, HV_BINOP_POW, 1, m, &cBinop_WVDeqsTt_sendMessage);
  cMsg_pGAgQum8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_9PrzHdCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_kr9YhYER, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_xk07ojSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pUV6PdVk, 1, m, &cIf_pUV6PdVk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_579KY922_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bo1n5vMk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bo1n5vMk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7UKyZ1ny, HV_BINOP_EQ, 1, m, &cBinop_7UKyZ1ny_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_hXDds92Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNgqiwHp, HV_BINOP_ADD, 0, m, &cBinop_gNgqiwHp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gNgqiwHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SrjVvXNs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O6LYOiX8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bo1n5vMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9PrzHdCr, 1, m, &cIf_9PrzHdCr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7UKyZ1ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYf4Wpmq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PYf4Wpmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kr9YhYER, m);
}

void Heavy_WSTD_EQ::cCast_8AbFi1u1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a97w3YIn, 0, m, &cVar_a97w3YIn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aHiX0Yp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hXDds92Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_fNDQ7rmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNgqiwHp, HV_BINOP_ADD, 1, m, &cBinop_gNgqiwHp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bo1n5vMk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bo1n5vMk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7UKyZ1ny, HV_BINOP_EQ, 0, m, &cBinop_7UKyZ1ny_sendMessage);
}

void Heavy_WSTD_EQ::cVar_b4MUctzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kFTSNJgt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ajtQ93YB, 0, m, &cIf_ajtQ93YB_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ajtQ93YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CdCreFtU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_upWDoD8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_I5Po5TLt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FoMMILB8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_qdBoKCM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hb0IPcSV, HV_BINOP_POW, 0, m, &cBinop_Hb0IPcSV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hb0IPcSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9FUbPINS, 0, m, &cIf_9FUbPINS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FvweNATG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cZDIxKdf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jEgoaONa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eLVQKiQY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_foo56Fov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_upWDoD8D, 0, m, &cIf_upWDoD8D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eLVQKiQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_upWDoD8D, 1, m, &cIf_upWDoD8D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FoMMILB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FvweNATG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_I5Po5TLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9FUbPINS, 0, m, &cIf_9FUbPINS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cZDIxKdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hb0IPcSV, HV_BINOP_POW, 1, m, &cBinop_Hb0IPcSV_sendMessage);
  cMsg_qdBoKCM9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_9FUbPINS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Sd3sSc3_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vUGLgJoo_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_8ujYHiZY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_kFTSNJgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ajtQ93YB, 1, m, &cIf_ajtQ93YB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CdCreFtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pU5uzzWt, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pU5uzzWt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3lcnEbVJ, HV_BINOP_EQ, 1, m, &cBinop_3lcnEbVJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WI3YNxYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RhNdCXIy, HV_BINOP_ADD, 0, m, &cBinop_RhNdCXIy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RhNdCXIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jEgoaONa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_foo56Fov_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pU5uzzWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9FUbPINS, 1, m, &cIf_9FUbPINS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3lcnEbVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hpZAHHOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hpZAHHOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Sd3sSc3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vUGLgJoo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_8ujYHiZY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gme3ie8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WI3YNxYV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_rRVdljH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RhNdCXIy, HV_BINOP_ADD, 1, m, &cBinop_RhNdCXIy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pU5uzzWt, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pU5uzzWt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3lcnEbVJ, HV_BINOP_EQ, 0, m, &cBinop_3lcnEbVJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MIitWzz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_b4MUctzZ, 0, m, &cVar_b4MUctzZ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ehzfcQ5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HEplePNE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rJMsYADP, 0, m, &cIf_rJMsYADP_sendMessage);
}

void Heavy_WSTD_EQ::cIf_rJMsYADP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mjapNxFy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_HW3tUEMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4AMD5dLJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_CAjEvRYx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_7HOM0QQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbcmteHL, HV_BINOP_POW, 0, m, &cBinop_JbcmteHL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JbcmteHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YVtkXLkd, 0, m, &cIf_YVtkXLkd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0en2TaMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_O2C2tw7j_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nsxuh9FT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HW3tUEMc, 0, m, &cIf_HW3tUEMc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ncNNvx0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZW46w3RO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZW46w3RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HW3tUEMc, 1, m, &cIf_HW3tUEMc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CAjEvRYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0en2TaMA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4AMD5dLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YVtkXLkd, 0, m, &cIf_YVtkXLkd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O2C2tw7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbcmteHL, HV_BINOP_POW, 1, m, &cBinop_JbcmteHL_sendMessage);
  cMsg_7HOM0QQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_YVtkXLkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_4GEok2s3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_HEplePNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rJMsYADP, 1, m, &cIf_rJMsYADP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mjapNxFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r6DhJCnC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_r6DhJCnC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w9pKziuE, HV_BINOP_EQ, 1, m, &cBinop_w9pKziuE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_j5b008xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxvxIrle, HV_BINOP_ADD, 0, m, &cBinop_qxvxIrle_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qxvxIrle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ncNNvx0p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nsxuh9FT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_r6DhJCnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YVtkXLkd, 1, m, &cIf_YVtkXLkd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_w9pKziuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OT1I7pGW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_OT1I7pGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4GEok2s3, m);
}

void Heavy_WSTD_EQ::cCast_TNAaWASQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxvxIrle, HV_BINOP_ADD, 1, m, &cBinop_qxvxIrle_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r6DhJCnC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_r6DhJCnC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w9pKziuE, HV_BINOP_EQ, 0, m, &cBinop_w9pKziuE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ynxR55JD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ehzfcQ5C, 0, m, &cVar_ehzfcQ5C_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PcQqNS4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j5b008xN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_l5obNlmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tOsnwONB, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_f2evRMJg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xaZVwjhF, 0, m, &cSlice_xaZVwjhF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IS5M6AsU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_xaZVwjhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7bTGOvbJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7bTGOvbJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_tXD8LvTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7bTGOvbJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7bTGOvbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ISiI3bbp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_IS5M6AsU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IGaL5Ofo, 0, m, &cSlice_IGaL5Ofo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dNV0Fjh0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_IGaL5Ofo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sleXp9Xz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sleXp9Xz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_zRuoaZ4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sleXp9Xz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_sleXp9Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gFbfCEZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_5sxedG52_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sDcxCJHd, 0, m, &cSlice_sDcxCJHd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EziWMbyT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_sDcxCJHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ec4z7Lhl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ec4z7Lhl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_2s6zVuJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ec4z7Lhl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ec4z7Lhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1kVyjuOi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_EziWMbyT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YCWEXxWM, 0, m, &cSlice_YCWEXxWM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_YCWEXxWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P1uYmin1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P1uYmin1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_8TbCBq7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P1uYmin1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_P1uYmin1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9OSrPYjC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gn4QKeQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iP6yz6CU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_VELuWz5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8OnvMezE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_p72uAoCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cdQmqmFo, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_lqbH0VkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ijiHDqQI, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_woPWCg6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xWB5X9IX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FNkamWuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JtAcwcPV_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_JtAcwcPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vr174ui3, HV_BINOP_DIVIDE, 1, m, &cBinop_Vr174ui3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z8tpq8ec_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_SC3W7pNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_CW8Vlu3g_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_m2ndUoKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_SC3W7pNt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CW8Vlu3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vr174ui3, HV_BINOP_DIVIDE, 0, m, &cBinop_Vr174ui3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Z8tpq8ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m2ndUoKW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Vr174ui3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6gD547Hn, HV_BINOP_MULTIPLY, 1, m, &cBinop_6gD547Hn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6gD547Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yfc34fsc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6X31aCRf_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_iSwKt1nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yRoAWrbM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_ORd3Gx0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cVYEktPk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ebCKaulR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xv8sgFYc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xv8sgFYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6gD547Hn, HV_BINOP_MULTIPLY, 0, m, &cBinop_6gD547Hn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ljFFU5cI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_h1mb0x73_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h1mb0x73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJyXoN6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Gkmyvk46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_72vqfQOq, 1, m, &cVar_72vqfQOq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_72vqfQOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N2gAvd2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ecxCOWtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2aRtCfH, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z2aRtCfH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rdschpIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ecxCOWtL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b0sWeJR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NeImPxRO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NeImPxRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O6qw4dtH, HV_BINOP_MULTIPLY, 1, m, &cBinop_O6qw4dtH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_I8qlCjMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3e5rXzc3, HV_BINOP_MULTIPLY, 1, m, &cBinop_3e5rXzc3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tfARwChJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I8qlCjMx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IM5AaKFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KU27PBjY, HV_BINOP_MULTIPLY, 1, m, &cBinop_KU27PBjY_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_033iYqn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uhwdN1FS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uhwdN1FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IUfK5lCN, HV_BINOP_MULTIPLY, 1, m, &cBinop_IUfK5lCN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_3dWfCYSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cqqz5484_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ebCKaulR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_maDgQmsq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_SSkaZywK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ljFFU5cI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6X31aCRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ORd3Gx0B_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Yfc34fsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_iSwKt1nu_sendMessage);
}

void Heavy_WSTD_EQ::cSend_yRoAWrbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_epJTOwpi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_cVYEktPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BFvh9tQX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_YUO506Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4Vr5BuAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_FJyXoN6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DLOpJpqy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DLOpJpqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l5dNVz3f, HV_BINOP_MULTIPLY, 1, m, &cBinop_l5dNVz3f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_l5dNVz3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zNPXaqoJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zNPXaqoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YUO506Ok_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_N2gAvd2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2uVopGFt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2uVopGFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MDKo8DxY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dr9EceZG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9l5bnPHk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R0zh8tDJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JuuTOkAC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hczVUXw0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z2aRtCfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gn4QKeQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_O6qw4dtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VELuWz5k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3e5rXzc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p72uAoCK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KU27PBjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lqbH0VkF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IUfK5lCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_woPWCg6f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_4LITggaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SSkaZywK, 1, m, &cVar_SSkaZywK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gVoEPJol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3dWfCYSA, 0, m, &cVar_3dWfCYSA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hczVUXw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2aRtCfH, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z2aRtCfH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9l5bnPHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KU27PBjY, HV_BINOP_MULTIPLY, 0, m, &cBinop_KU27PBjY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JuuTOkAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O6qw4dtH, HV_BINOP_MULTIPLY, 0, m, &cBinop_O6qw4dtH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Dr9EceZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IUfK5lCN, HV_BINOP_MULTIPLY, 0, m, &cBinop_IUfK5lCN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_R0zh8tDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3e5rXzc3, HV_BINOP_MULTIPLY, 0, m, &cBinop_3e5rXzc3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MDKo8DxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_maDgQmsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_72vqfQOq, 0, m, &cVar_72vqfQOq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cqqz5484_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SSkaZywK, 0, m, &cVar_SSkaZywK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lCkwOK4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HzWAWCWw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_TfUrYq4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oTo8SFxu, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dykzIaZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XI1rMwky, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wKmfuzLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EdX5kXCM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BokV8TYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y1VPcmvX_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_y1VPcmvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GrlYN0wU, HV_BINOP_DIVIDE, 1, m, &cBinop_GrlYN0wU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_98qFMGHR_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9nRvh2YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_yR9xtWUr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Fh4umWRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9nRvh2YH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yR9xtWUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GrlYN0wU, HV_BINOP_DIVIDE, 0, m, &cBinop_GrlYN0wU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_98qFMGHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fh4umWRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GrlYN0wU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MJC2GK5k, HV_BINOP_MULTIPLY, 1, m, &cBinop_MJC2GK5k_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MJC2GK5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rekUBaWu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeuJMPqC_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_op3WWeaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rCwZiduz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_9DlziKV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r785JQ3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_039HinPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_4e2y1uOd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4e2y1uOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MJC2GK5k, HV_BINOP_MULTIPLY, 0, m, &cBinop_MJC2GK5k_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aGdod4k6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_thSqBbwY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_thSqBbwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AE1sdfhD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_P7tOLzAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TTPeltzL, HV_BINOP_MULTIPLY, 1, m, &cBinop_TTPeltzL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nrKXnUM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ujo1I6uG, 1, m, &cVar_ujo1I6uG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OvTA42WB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XPy2t6jP, HV_BINOP_MULTIPLY, 1, m, &cBinop_XPy2t6jP_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Hy3d7QPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vwoh2q7j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vwoh2q7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHmCJgV5, HV_BINOP_MULTIPLY, 1, m, &cBinop_qHmCJgV5_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ujo1I6uG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BpfIAWqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ky1FEugh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AVTpkGOG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_039HinPL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yE23ABpX_sendMessage);
}

void Heavy_WSTD_EQ::cVar_LHNSxI3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_aGdod4k6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rekUBaWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_op3WWeaU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yeuJMPqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9DlziKV9_sendMessage);
}

void Heavy_WSTD_EQ::cSend_rCwZiduz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_16oiUCye_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_r785JQ3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U1C9aDwc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GzEWbO07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NXzTrIWh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_AE1sdfhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wKOEb51Z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wKOEb51Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ml5pUEKn, HV_BINOP_MULTIPLY, 1, m, &cBinop_ml5pUEKn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ml5pUEKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vWFOzzS9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vWFOzzS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GzEWbO07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_BpfIAWqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EH4z2hLH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EH4z2hLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aptJU4u7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lb56Qete_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uUB84zei_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3fwuuKax_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pdl7dCD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lCkwOK4W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TTPeltzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TfUrYq4L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XPy2t6jP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dykzIaZR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qHmCJgV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wKmfuzLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_YQvLBuci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LHNSxI3A, 1, m, &cVar_LHNSxI3A_sendMessage);
}

void Heavy_WSTD_EQ::cCast_p90VNA4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ky1FEugh, 0, m, &cVar_ky1FEugh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yE23ABpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ujo1I6uG, 0, m, &cVar_ujo1I6uG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AVTpkGOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LHNSxI3A, 0, m, &cVar_LHNSxI3A_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uUB84zei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TTPeltzL, HV_BINOP_MULTIPLY, 0, m, &cBinop_TTPeltzL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lb56Qete_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XPy2t6jP, HV_BINOP_MULTIPLY, 0, m, &cBinop_XPy2t6jP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3fwuuKax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdl7dCD5, HV_BINOP_MULTIPLY, 0, m, &cBinop_pdl7dCD5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aptJU4u7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHmCJgV5, HV_BINOP_MULTIPLY, 0, m, &cBinop_qHmCJgV5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5PDWp6VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0kKQUjss, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_N6faCVAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NUMDYUB1, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0kfTy20c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t8aUU01Q, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_k6KQxpT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oKGddUhG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wRPtsUHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nWukp65t, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_afnMZ2z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r3Ph3QRG_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_r3Ph3QRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRQzKOk6, HV_BINOP_DIVIDE, 1, m, &cBinop_gRQzKOk6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y12cMrIV_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_eFipqedp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_u3JPqnMf_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_L1wru0zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eFipqedp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u3JPqnMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRQzKOk6, HV_BINOP_DIVIDE, 0, m, &cBinop_gRQzKOk6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Y12cMrIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L1wru0zN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gRQzKOk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_guZqjUzz, HV_BINOP_MULTIPLY, 1, m, &cBinop_guZqjUzz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_guZqjUzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cFLumcLU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MjM5VPlB_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_uyMMVXiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j23Vu4I1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_MEoDtAAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fDXqHrvK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HlivIChL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_yyZm0f7U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yyZm0f7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_guZqjUzz, HV_BINOP_MULTIPLY, 0, m, &cBinop_guZqjUzz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sJquktlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GOJKJE2X_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GOJKJE2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2NO9mUf4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pf8B3Mj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M05cvBoY, HV_BINOP_MULTIPLY, 1, m, &cBinop_M05cvBoY_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_N4yAZZP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kzf208zt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kzf208zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pf8B3Mj9_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_pEXE8tDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7ncBeCTi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7ncBeCTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nOmRXn3K, HV_BINOP_MULTIPLY, 1, m, &cBinop_nOmRXn3K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bNA7eLYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KlN4ypJZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_KlN4ypJZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uGTRWfef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_V96lTWDz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V96lTWDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bNA7eLYS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pussel5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YT9VGVUi, 1, m, &cVar_YT9VGVUi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Sm8aMxjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7aoL4AGu, HV_BINOP_MULTIPLY, 1, m, &cBinop_7aoL4AGu_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tngKftDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XT3FnaQB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XT3FnaQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUswEpTM, HV_BINOP_MULTIPLY, 1, m, &cBinop_zUswEpTM_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YT9VGVUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_69qB2q9v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_lm6GsbPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9XLy0E3z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HlivIChL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DCYg6Myj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Cjj5G0Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sJquktlg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cFLumcLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uyMMVXiJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MjM5VPlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_MEoDtAAP_sendMessage);
}

void Heavy_WSTD_EQ::cSend_j23Vu4I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rCKYa1wq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fDXqHrvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lgo5iZQJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_iXiR1RpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HM9HNkvx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_2NO9mUf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AwMjYnSO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AwMjYnSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nevcuytJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_nevcuytJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nevcuytJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_skJtIVEe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_skJtIVEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iXiR1RpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_69qB2q9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lfKaUURm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lfKaUURm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghkxgaC0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bdTfkyOk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xU9fSZ5r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AWw06U8q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BUvAOmYh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fodl2IVu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M05cvBoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5PDWp6VM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nOmRXn3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N6faCVAs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KlN4ypJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0kfTy20c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7aoL4AGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k6KQxpT2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zUswEpTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wRPtsUHn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_BcMnV1Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cjj5G0Is, 1, m, &cVar_Cjj5G0Is_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bwe6fDxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lm6GsbPy, 0, m, &cVar_lm6GsbPy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BUvAOmYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nOmRXn3K, HV_BINOP_MULTIPLY, 0, m, &cBinop_nOmRXn3K_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bdTfkyOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUswEpTM, HV_BINOP_MULTIPLY, 0, m, &cBinop_zUswEpTM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AWw06U8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KlN4ypJZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_KlN4ypJZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ghkxgaC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_fodl2IVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M05cvBoY, HV_BINOP_MULTIPLY, 0, m, &cBinop_M05cvBoY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xU9fSZ5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7aoL4AGu, HV_BINOP_MULTIPLY, 0, m, &cBinop_7aoL4AGu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9XLy0E3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cjj5G0Is, 0, m, &cVar_Cjj5G0Is_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DCYg6Myj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YT9VGVUi, 0, m, &cVar_YT9VGVUi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5Sd3sSc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l5obNlmR, 1, m, &cIf_l5obNlmR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cp0PKnca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tOsnwONB, m);
}

void Heavy_WSTD_EQ::cBinop_vUGLgJoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cp0PKnca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8ujYHiZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l5obNlmR, 0, m, &cIf_l5obNlmR_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_0WI0dM24_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xc1hEv6Y, 0, m, &cSlice_xc1hEv6Y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fOrf8uI0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_xc1hEv6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_W5kA0K47_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_W5kA0K47_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Uz8SJkJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W5kA0K47_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_W5kA0K47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gJwZW3iE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ONlAi4Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aHHf3brG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RT5BbkTz, 0, m, &cIf_RT5BbkTz_sendMessage);
}

void Heavy_WSTD_EQ::cIf_RT5BbkTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FBXFEkKc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_GQsYLblu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SKd7S6vM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_86GsA0vg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_EP5dAIBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMTCuTQW, HV_BINOP_POW, 0, m, &cBinop_bMTCuTQW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bMTCuTQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KFaOgsh7, 0, m, &cIf_KFaOgsh7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YHIpcPoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_H42FVKDE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZSME2C5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GQsYLblu, 0, m, &cIf_GQsYLblu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RbBUcFq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XtaxcDA1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XtaxcDA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GQsYLblu, 1, m, &cIf_GQsYLblu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_86GsA0vg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YHIpcPoC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SKd7S6vM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_KFaOgsh7, 0, m, &cIf_KFaOgsh7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H42FVKDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMTCuTQW, HV_BINOP_POW, 1, m, &cBinop_bMTCuTQW_sendMessage);
  cMsg_EP5dAIBc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_KFaOgsh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_CFvQd8CY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_aHHf3brG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RT5BbkTz, 1, m, &cIf_RT5BbkTz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FBXFEkKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHe1pjds, HV_BINOP_GREATER_THAN, 1, m, &cBinop_RHe1pjds_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNQFYHtS, HV_BINOP_EQ, 1, m, &cBinop_wNQFYHtS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GW9HDnbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_prPOtdUZ, HV_BINOP_ADD, 0, m, &cBinop_prPOtdUZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_prPOtdUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RbBUcFq6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZSME2C5q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RHe1pjds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KFaOgsh7, 1, m, &cIf_KFaOgsh7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wNQFYHtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNl42d9b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZNl42d9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CFvQd8CY, m);
}

void Heavy_WSTD_EQ::cCast_RNUy3nFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_prPOtdUZ, HV_BINOP_ADD, 1, m, &cBinop_prPOtdUZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHe1pjds, HV_BINOP_GREATER_THAN, 0, m, &cBinop_RHe1pjds_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNQFYHtS, HV_BINOP_EQ, 0, m, &cBinop_wNQFYHtS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UL3TYZB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ONlAi4Ou, 0, m, &cVar_ONlAi4Ou_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lj9JbExO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GW9HDnbC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_8KHOLavE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Eiz8vMcb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_b6uqQXnz, 0, m, &cIf_b6uqQXnz_sendMessage);
}

void Heavy_WSTD_EQ::cIf_b6uqQXnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Otfu2Gvq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_gsS9RXmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bRtJBvv1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PGUeUGuj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_z0lmg0yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEoRrSzS, HV_BINOP_POW, 0, m, &cBinop_dEoRrSzS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dEoRrSzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pw9oIklt, 0, m, &cIf_pw9oIklt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pAA3ltpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vwUjd1Bs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6FGVAho2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sPfpgoEj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_i9wz4MOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gsS9RXmD, 0, m, &cIf_gsS9RXmD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sPfpgoEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gsS9RXmD, 1, m, &cIf_gsS9RXmD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PGUeUGuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pAA3ltpG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bRtJBvv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pw9oIklt, 0, m, &cIf_pw9oIklt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vwUjd1Bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEoRrSzS, HV_BINOP_POW, 1, m, &cBinop_dEoRrSzS_sendMessage);
  cMsg_z0lmg0yG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_pw9oIklt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dIwqDxO3_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MQMOLiFv_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_oQxpCLCK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_Eiz8vMcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b6uqQXnz, 1, m, &cIf_b6uqQXnz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Otfu2Gvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wSlPhLEp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wSlPhLEp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3aqBpK9z, HV_BINOP_EQ, 1, m, &cBinop_3aqBpK9z_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kdt1MntY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ucjWzWl9, HV_BINOP_ADD, 0, m, &cBinop_ucjWzWl9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ucjWzWl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6FGVAho2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i9wz4MOl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wSlPhLEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pw9oIklt, 1, m, &cIf_pw9oIklt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3aqBpK9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WB9hFmbJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_WB9hFmbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dIwqDxO3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MQMOLiFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_oQxpCLCK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ONEcsOtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kdt1MntY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_3Axnpq57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ucjWzWl9, HV_BINOP_ADD, 1, m, &cBinop_ucjWzWl9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wSlPhLEp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wSlPhLEp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3aqBpK9z, HV_BINOP_EQ, 0, m, &cBinop_3aqBpK9z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ei9dy345_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8KHOLavE, 0, m, &cVar_8KHOLavE_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5pBKOO9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RLilui3r_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_GsVPL0Hf, 0, m, &cIf_GsVPL0Hf_sendMessage);
}

void Heavy_WSTD_EQ::cIf_GsVPL0Hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dvnGszcG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_i87avm1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vO2lXG4O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_gbxJfT2R_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_CT7sVt2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mtm8sTmI, HV_BINOP_POW, 0, m, &cBinop_Mtm8sTmI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Mtm8sTmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aOeZE8Sp, 0, m, &cIf_aOeZE8Sp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LwjnulEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_uxYNIDhW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_igpMleVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_odUT2GsN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SZ3VciG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i87avm1P, 0, m, &cIf_i87avm1P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_odUT2GsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i87avm1P, 1, m, &cIf_i87avm1P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gbxJfT2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_LwjnulEk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vO2lXG4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aOeZE8Sp, 0, m, &cIf_aOeZE8Sp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uxYNIDhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mtm8sTmI, HV_BINOP_POW, 1, m, &cBinop_Mtm8sTmI_sendMessage);
  cMsg_CT7sVt2Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_aOeZE8Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tRB4Txqn, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_RLilui3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GsVPL0Hf, 1, m, &cIf_GsVPL0Hf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dvnGszcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZAjSQtKV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZAjSQtKV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NPy2a4ld, HV_BINOP_EQ, 1, m, &cBinop_NPy2a4ld_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9NW7O5D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpLChUNi, HV_BINOP_ADD, 0, m, &cBinop_MpLChUNi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MpLChUNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_igpMleVK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SZ3VciG9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZAjSQtKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aOeZE8Sp, 1, m, &cIf_aOeZE8Sp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NPy2a4ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MST1kEWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_MST1kEWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tRB4Txqn, m);
}

void Heavy_WSTD_EQ::cCast_fjqSqH9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9NW7O5D5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_R8F1VBRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5pBKOO9U, 0, m, &cVar_5pBKOO9U_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LCkSF330_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpLChUNi, HV_BINOP_ADD, 1, m, &cBinop_MpLChUNi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZAjSQtKV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZAjSQtKV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NPy2a4ld, HV_BINOP_EQ, 0, m, &cBinop_NPy2a4ld_sendMessage);
}

void Heavy_WSTD_EQ::cIf_GTZMh7SA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_xdvl9hUn, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_Fuelhzbk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gtPdwDdn, 0, m, &cSlice_gtPdwDdn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PKZzwAkD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_gtPdwDdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ETYLNQTE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ETYLNQTE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Wm0SNXxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ETYLNQTE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ETYLNQTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_51G6GvlG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_PKZzwAkD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_W0aAyX9R, 0, m, &cSlice_W0aAyX9R_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0WI0dM24_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_W0aAyX9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NBdTF5TI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NBdTF5TI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_CXrX7AU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NBdTF5TI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NBdTF5TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6nz8HwMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_fOrf8uI0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4F6CGifG, 0, m, &cSlice_4F6CGifG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9Qz15I8n_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_4F6CGifG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_42feBN0c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_42feBN0c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_zAMTPvsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_42feBN0c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_42feBN0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T0oPiE4u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_9Qz15I8n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LSkHn7p6, 0, m, &cSlice_LSkHn7p6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_LSkHn7p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MY5FUT1b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MY5FUT1b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_hOeb78DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MY5FUT1b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_MY5FUT1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6vlFIjDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_MxIpcuLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SXIYZcOU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GW91a5X5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CW4pAlgA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_PfiWSRgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j83FWTJF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_vfbIdkiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lW79zaPq, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IFC343Cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_82MiiZWy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bLLEn5EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eNui32Gx_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_eNui32Gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2lBt0gbX, HV_BINOP_DIVIDE, 1, m, &cBinop_2lBt0gbX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BVJ1bvTY_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Zc3GGoZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_hUVVirer_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mw8l3SVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Zc3GGoZy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hUVVirer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2lBt0gbX, HV_BINOP_DIVIDE, 0, m, &cBinop_2lBt0gbX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BVJ1bvTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mw8l3SVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2lBt0gbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K3CDJGd4, HV_BINOP_MULTIPLY, 1, m, &cBinop_K3CDJGd4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K3CDJGd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iPpg6H06_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VHUKV6L7_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Wvb8CLd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7cd8SCnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_v9ziS4BP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VAb4OKbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ILBLEdrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Qb5zRN7f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qb5zRN7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K3CDJGd4, HV_BINOP_MULTIPLY, 0, m, &cBinop_K3CDJGd4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rwg5cJMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_hTbKovjy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hTbKovjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UARNWrJE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rC9kwlJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SFzTQHaj, 1, m, &cVar_SFzTQHaj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_SFzTQHaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jhjsYv6p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7hHTziES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1tKw2Zc7, HV_BINOP_MULTIPLY, 1, m, &cBinop_1tKw2Zc7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yMzdTFUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7hHTziES_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ABe2dxAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_K7I96gA4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K7I96gA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmBjw55K, HV_BINOP_MULTIPLY, 1, m, &cBinop_wmBjw55K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TwXvcpL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9CdA3PWY, HV_BINOP_MULTIPLY, 1, m, &cBinop_9CdA3PWY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9ET8OQzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TwXvcpL2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cNaBSSY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zE28I1bj, HV_BINOP_MULTIPLY, 1, m, &cBinop_zE28I1bj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9mxfChtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SAruXKul_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SAruXKul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xce3pJM8, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xce3pJM8_sendMessage);
}

void Heavy_WSTD_EQ::cVar_f2URHIfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cDNudvQU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ILBLEdrV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xqPdmRdG_sendMessage);
}

void Heavy_WSTD_EQ::cVar_p64lBeQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rwg5cJMJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iPpg6H06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Wvb8CLd5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VHUKV6L7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_v9ziS4BP_sendMessage);
}

void Heavy_WSTD_EQ::cSend_7cd8SCnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9aGfyf4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VAb4OKbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rPAsSl97_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_AYEw8hZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IwkbYP7S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_UARNWrJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_O4JQFJgI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O4JQFJgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nh0DCFtZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_nh0DCFtZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nh0DCFtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_akHQD1VS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_akHQD1VS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AYEw8hZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_jhjsYv6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_drIxQccg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_drIxQccg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2X68rkj1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HT51qJGC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q3xd8myH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gAv47LSJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oBO4UPy7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zT6E2HHb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1tKw2Zc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MxIpcuLx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wmBjw55K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GW91a5X5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9CdA3PWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PfiWSRgb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zE28I1bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vfbIdkiB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Xce3pJM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IFC343Cy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_i9kJyE5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f2URHIfG, 0, m, &cVar_f2URHIfG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_g3vcggFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p64lBeQs, 1, m, &cVar_p64lBeQs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gAv47LSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9CdA3PWY, HV_BINOP_MULTIPLY, 0, m, &cBinop_9CdA3PWY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2X68rkj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_zT6E2HHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1tKw2Zc7, HV_BINOP_MULTIPLY, 0, m, &cBinop_1tKw2Zc7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q3xd8myH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zE28I1bj, HV_BINOP_MULTIPLY, 0, m, &cBinop_zE28I1bj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oBO4UPy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmBjw55K, HV_BINOP_MULTIPLY, 0, m, &cBinop_wmBjw55K_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HT51qJGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xce3pJM8, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xce3pJM8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cDNudvQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p64lBeQs, 0, m, &cVar_p64lBeQs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xqPdmRdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SFzTQHaj, 0, m, &cVar_SFzTQHaj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_epmv7p1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RxHQYPWS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Fh1aLuHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MGkfFXxB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4U8cjr5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hfJjCx0B, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dpYFig24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SF1XYWhJ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JEkxqMo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7Ae4pyWT_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_7Ae4pyWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FszjIknT, HV_BINOP_DIVIDE, 1, m, &cBinop_FszjIknT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PgvPysQa_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_3xcwTLiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QTrgx3GD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZHoyXoGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3xcwTLiw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QTrgx3GD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FszjIknT, HV_BINOP_DIVIDE, 0, m, &cBinop_FszjIknT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PgvPysQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZHoyXoGy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FszjIknT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FUGYJQUG, HV_BINOP_MULTIPLY, 1, m, &cBinop_FUGYJQUG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FUGYJQUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EvbnT76C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UhEXpQHA_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_5AbFweVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pf3nlJYM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_13Va9DD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sbiYWidd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2BTrvdoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0zkBfVl5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0zkBfVl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FUGYJQUG, HV_BINOP_MULTIPLY, 0, m, &cBinop_FUGYJQUG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oYySgIe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DRQrytp9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DRQrytp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YAOD1DUo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pDwxNnnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vzzz6NRT, HV_BINOP_MULTIPLY, 1, m, &cBinop_vzzz6NRT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TDc2eNv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ix1uXTNJ, 1, m, &cVar_ix1uXTNJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lgBq5lXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ecSZeBkx, HV_BINOP_MULTIPLY, 1, m, &cBinop_ecSZeBkx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2rqxU30c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GSnMlE5O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GSnMlE5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R2tcJwCQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_R2tcJwCQ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ix1uXTNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tQcgyrJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_0gSv4WIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HEg9CWS1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_2BTrvdoH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hjqcIlsr_sendMessage);
}

void Heavy_WSTD_EQ::cVar_erxDMBKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oYySgIe9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EvbnT76C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5AbFweVI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UhEXpQHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_13Va9DD7_sendMessage);
}

void Heavy_WSTD_EQ::cSend_pf3nlJYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lWuIRsSv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_sbiYWidd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fyDWDISa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Eruv4DUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gre0t0PD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_YAOD1DUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zeXXSTbI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zeXXSTbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sUbIPOxQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_sUbIPOxQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sUbIPOxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zZRVvfQ2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zZRVvfQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Eruv4DUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_tQcgyrJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B2b6WUyR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_B2b6WUyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7G9ZqHC8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W6AzdvGS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zib3Gkq1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rrpFwIiy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0L0akxop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_epmv7p1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vzzz6NRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fh1aLuHh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ecSZeBkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4U8cjr5v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_R2tcJwCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dpYFig24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_fvGBHevo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_erxDMBKN, 1, m, &cVar_erxDMBKN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V4z9Y6iA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0gSv4WIY, 0, m, &cVar_0gSv4WIY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hjqcIlsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ix1uXTNJ, 0, m, &cVar_ix1uXTNJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HEg9CWS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_erxDMBKN, 0, m, &cVar_erxDMBKN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Zib3Gkq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vzzz6NRT, HV_BINOP_MULTIPLY, 0, m, &cBinop_vzzz6NRT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_W6AzdvGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ecSZeBkx, HV_BINOP_MULTIPLY, 0, m, &cBinop_ecSZeBkx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rrpFwIiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0L0akxop, HV_BINOP_MULTIPLY, 0, m, &cBinop_0L0akxop_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7G9ZqHC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R2tcJwCQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_R2tcJwCQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BfP0atDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKv7R6RQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_J2O15mBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UIaLReIg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_euhHHfIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VUl86IV5, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mnmb8E3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pefKNPHT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_iEdk6zqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M3uYUFF8, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_m8IA0LZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Jes4dqBw_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Jes4dqBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_enkhrVY1, HV_BINOP_DIVIDE, 1, m, &cBinop_enkhrVY1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZWChMUg3_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_TDPWpd4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_5QQZ8iBD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vk3PY6yC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_TDPWpd4t_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5QQZ8iBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_enkhrVY1, HV_BINOP_DIVIDE, 0, m, &cBinop_enkhrVY1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZWChMUg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vk3PY6yC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_enkhrVY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PdJGNjup, HV_BINOP_MULTIPLY, 1, m, &cBinop_PdJGNjup_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PdJGNjup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VNx4ybcn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PMKCfwML_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_qogrlsV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_K7KRRkb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_SL4HITQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0gkMoN3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_r2EmusFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Ke42Xfyp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ke42Xfyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PdJGNjup, HV_BINOP_MULTIPLY, 0, m, &cBinop_PdJGNjup_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qrrEExjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_vcSJxknM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vcSJxknM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CCYoZtn7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6LkqnIrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WaVg4eTy, HV_BINOP_MULTIPLY, 1, m, &cBinop_WaVg4eTy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XTdGHaB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JnpmaF2Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JnpmaF2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6LkqnIrs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sQBgCqvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JiYaMTyC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JiYaMTyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ooCAz8Cp, HV_BINOP_MULTIPLY, 1, m, &cBinop_ooCAz8Cp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EVYUWR0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FjZrFvv3, HV_BINOP_MULTIPLY, 1, m, &cBinop_FjZrFvv3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_u9Kb7nDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UPJpPeoi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UPJpPeoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EVYUWR0M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m6P0ORxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ijlGUrNi, 1, m, &cVar_ijlGUrNi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xRdvo4oU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gJqQKZ31, HV_BINOP_MULTIPLY, 1, m, &cBinop_gJqQKZ31_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VUVevOPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1ef8aTuz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1ef8aTuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_al2qBViA, HV_BINOP_MULTIPLY, 1, m, &cBinop_al2qBViA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ijlGUrNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5KEpUVLf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_lFMLigsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1hQ0ZwZi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_r2EmusFc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pXFAuZnv_sendMessage);
}

void Heavy_WSTD_EQ::cVar_0KYTh826_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qrrEExjV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PMKCfwML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SL4HITQ0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VNx4ybcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qogrlsV5_sendMessage);
}

void Heavy_WSTD_EQ::cSend_K7KRRkb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f1FQ97Nq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_0gkMoN3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8OJzxXlp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7x1wLEsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ihQ9V0Fq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_CCYoZtn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hA4UTIKX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hA4UTIKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IzgNYbws, HV_BINOP_MULTIPLY, 1, m, &cBinop_IzgNYbws_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IzgNYbws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_meJRR334_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_meJRR334_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7x1wLEsh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_5KEpUVLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wBrrSpWe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wBrrSpWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xUrxiFCa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XKpJJ0OT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TVUEPxeF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_42wDLq1x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ew07y0RG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T3MBqz2m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WaVg4eTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BfP0atDQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ooCAz8Cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J2O15mBh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FjZrFvv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_euhHHfIJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gJqQKZ31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mnmb8E3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_al2qBViA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iEdk6zqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_OKzc8GMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0KYTh826, 1, m, &cVar_0KYTh826_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yvaLNrdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lFMLigsH, 0, m, &cVar_lFMLigsH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ew07y0RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ooCAz8Cp, HV_BINOP_MULTIPLY, 0, m, &cBinop_ooCAz8Cp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XKpJJ0OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_al2qBViA, HV_BINOP_MULTIPLY, 0, m, &cBinop_al2qBViA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_42wDLq1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FjZrFvv3, HV_BINOP_MULTIPLY, 0, m, &cBinop_FjZrFvv3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xUrxiFCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_T3MBqz2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WaVg4eTy, HV_BINOP_MULTIPLY, 0, m, &cBinop_WaVg4eTy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TVUEPxeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gJqQKZ31, HV_BINOP_MULTIPLY, 0, m, &cBinop_gJqQKZ31_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1hQ0ZwZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0KYTh826, 0, m, &cVar_0KYTh826_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pXFAuZnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ijlGUrNi, 0, m, &cVar_ijlGUrNi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dIwqDxO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GTZMh7SA, 1, m, &cIf_GTZMh7SA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_nypf8UDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xdvl9hUn, m);
}

void Heavy_WSTD_EQ::cBinop_MQMOLiFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nypf8UDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oQxpCLCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GTZMh7SA, 0, m, &cIf_GTZMh7SA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_dDkYZ3p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rFhsUKnw, HV_BINOP_DIVIDE, 0, m, &cBinop_rFhsUKnw_sendMessage);
}

void Heavy_WSTD_EQ::cVar_sph1nIaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uJXiQNfa, HV_BINOP_DIVIDE, 1, m, &cBinop_uJXiQNfa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rFhsUKnw, HV_BINOP_DIVIDE, 1, m, &cBinop_rFhsUKnw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_jkcOavng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FtrjENw, HV_BINOP_DIVIDE, 0, m, &cBinop_0FtrjENw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_gde3Jq1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FtrjENw, HV_BINOP_DIVIDE, 1, m, &cBinop_0FtrjENw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pMWhM2yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uJXiQNfa, HV_BINOP_DIVIDE, 0, m, &cBinop_uJXiQNfa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2peKLijJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dDkYZ3p6, 0, m, &cVar_dDkYZ3p6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fXuqk1L3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sph1nIaU, 0, m, &cVar_sph1nIaU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uJXiQNfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_jkcOavng_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rFhsUKnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_gde3Jq1J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0FtrjENw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_e2rDZV42_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xB3uJOyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_hpjEZrnJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9IjZNcKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_3nsPdcvs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_e2rDZV42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9IjZNcKr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3nsPdcvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_xB3uJOyQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hpjEZrnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kt9Rhbjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_S4D23eA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2evRMJg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Fuelhzbk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4ZEfxxdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2evRMJg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Fuelhzbk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9eTyoPw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2evRMJg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Fuelhzbk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CrCqOLw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2evRMJg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Fuelhzbk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kt9Rhbjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2evRMJg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Fuelhzbk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_66ectCZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9179mRLT, 0, m, &cVar_9179mRLT_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_oQNXWpy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_qhGNABIr, 0, m, &cVar_qhGNABIr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3FiLQJXT, 0, m, &cVar_3FiLQJXT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sWSRt0Ct, 0, m, &cVar_sWSRt0Ct_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qAA6OGrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qhGNABIr, 0, m, &cVar_qhGNABIr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_VEu6CuHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3FiLQJXT, 0, m, &cVar_3FiLQJXT_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_x13twqip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sWSRt0Ct, 0, m, &cVar_sWSRt0Ct_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pC08Igqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ky1FEugh, 0, m, &cVar_ky1FEugh_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9OSrPYjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YQvLBuci_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p90VNA4U_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ISiI3bbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8AbFi1u1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fNDQ7rmG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aHiX0Yp9_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1kVyjuOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ynxR55JD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TNAaWASQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PcQqNS4X_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gFbfCEZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MIitWzz2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rRVdljH8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gme3ie8f_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ezKJD4wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FNkamWuP_sendMessage(_c, 0, m);
  cMsg_BokV8TYe_sendMessage(_c, 0, m);
  cMsg_afnMZ2z9_sendMessage(_c, 0, m);
  cMsg_bLLEn5EX_sendMessage(_c, 0, m);
  cMsg_JEkxqMo1_sendMessage(_c, 0, m);
  cMsg_m8IA0LZY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3dWfCYSA, 0, m, &cVar_3dWfCYSA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ky1FEugh, 0, m, &cVar_ky1FEugh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lm6GsbPy, 0, m, &cVar_lm6GsbPy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f2URHIfG, 0, m, &cVar_f2URHIfG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0gSv4WIY, 0, m, &cVar_0gSv4WIY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lFMLigsH, 0, m, &cVar_lFMLigsH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vOMXHZlR, 0, m, &cVar_vOMXHZlR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a97w3YIn, 0, m, &cVar_a97w3YIn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b4MUctzZ, 0, m, &cVar_b4MUctzZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ehzfcQ5C, 0, m, &cVar_ehzfcQ5C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tXD8LvTj, 0, m, &cVar_tXD8LvTj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zRuoaZ4W, 0, m, &cVar_zRuoaZ4W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2s6zVuJb, 0, m, &cVar_2s6zVuJb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8TbCBq7i, 0, m, &cVar_8TbCBq7i_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Uz8SJkJB, 0, m, &cVar_Uz8SJkJB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ONlAi4Ou, 0, m, &cVar_ONlAi4Ou_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8KHOLavE, 0, m, &cVar_8KHOLavE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5pBKOO9U, 0, m, &cVar_5pBKOO9U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wm0SNXxJ, 0, m, &cVar_Wm0SNXxJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CXrX7AU4, 0, m, &cVar_CXrX7AU4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zAMTPvsX, 0, m, &cVar_zAMTPvsX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hOeb78DF, 0, m, &cVar_hOeb78DF_sendMessage);
  cMsg_oQNXWpy0_sendMessage(_c, 0, m);
  cMsg_66ectCZo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_epJTOwpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l5dNVz3f, HV_BINOP_MULTIPLY, 0, m, &cBinop_l5dNVz3f_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_BFvh9tQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rdschpIy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_b0sWeJR4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tfARwChJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_IM5AaKFM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_4Vr5BuAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Gkmyvk46_sendMessage);
  cMsg_033iYqn8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_16oiUCye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ml5pUEKn, HV_BINOP_MULTIPLY, 0, m, &cBinop_ml5pUEKn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_U1C9aDwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_OvTA42WB_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_NXzTrIWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdl7dCD5, HV_BINOP_MULTIPLY, 1, m, &cBinop_pdl7dCD5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_P7tOLzAL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nrKXnUM6_sendMessage);
  cMsg_Hy3d7QPc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_rCKYa1wq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nevcuytJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_nevcuytJ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lgo5iZQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N4yAZZP6_sendMessage(_c, 0, m);
  cMsg_pEXE8tDk_sendMessage(_c, 0, m);
  cMsg_uGTRWfef_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Sm8aMxjL_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_HM9HNkvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pussel5W_sendMessage);
  cMsg_tngKftDX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_gJwZW3iE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0gSv4WIY, 0, m, &cVar_0gSv4WIY_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6vlFIjDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fvGBHevo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V4z9Y6iA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_51G6GvlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UL3TYZB3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RNUy3nFO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lj9JbExO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_T0oPiE4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R8F1VBRu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LCkSF330_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fjqSqH9U_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6nz8HwMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ei9dy345_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Axnpq57_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ONEcsOtT_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9aGfyf4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nh0DCFtZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_nh0DCFtZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rPAsSl97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yMzdTFUj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ABe2dxAS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9ET8OQzn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cNaBSSY3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IwkbYP7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rC9kwlJF_sendMessage);
  cMsg_9mxfChtK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_lWuIRsSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sUbIPOxQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_sUbIPOxQ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_fyDWDISa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_lgBq5lXJ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gre0t0PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0L0akxop, HV_BINOP_MULTIPLY, 1, m, &cBinop_0L0akxop_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pDwxNnnJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TDc2eNv8_sendMessage);
  cMsg_2rqxU30c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_f1FQ97Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IzgNYbws, HV_BINOP_MULTIPLY, 0, m, &cBinop_IzgNYbws_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_8OJzxXlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XTdGHaB4_sendMessage(_c, 0, m);
  cMsg_sQBgCqvP_sendMessage(_c, 0, m);
  cMsg_u9Kb7nDb_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_xRdvo4oU_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ihQ9V0Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_m6P0ORxY_sendMessage);
  cMsg_VUVevOPI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_z6bxYSBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9179mRLT, 0, m, &cVar_9179mRLT_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_sxFw4p9O, VOf(Bf0));
    __hv_varread_f(&sVarf_LRM9HkEV, VOf(Bf1));
    __hv_varread_f(&sVarf_3LPTPrnm, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_oVGDfpux, VOf(Bf0));
    __hv_varread_f(&sVarf_HBdbFLjY, VOf(Bf1));
    __hv_varread_f(&sVarf_SUFj5CV9, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_iP6yz6CU, VOf(Bf0));
    __hv_line_f(&sLine_8OnvMezE, VOf(Bf1));
    __hv_line_f(&sLine_cdQmqmFo, VOf(Bf4));
    __hv_line_f(&sLine_ijiHDqQI, VOf(Bf5));
    __hv_line_f(&sLine_xWB5X9IX, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_2nfkrUx2, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_kr9YhYER, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_HzWAWCWw, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_oTo8SFxu, VOf(Bf1));
    __hv_line_f(&sLine_XI1rMwky, VOf(Bf0));
    __hv_line_f(&sLine_EdX5kXCM, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_KQpCi64x, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_tOsnwONB, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_0kKQUjss, VOf(Bf7));
    __hv_line_f(&sLine_NUMDYUB1, VOf(Bf1));
    __hv_line_f(&sLine_t8aUU01Q, VOf(Bf4));
    __hv_line_f(&sLine_oKGddUhG, VOf(Bf6));
    __hv_line_f(&sLine_nWukp65t, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_pXkl1OUz, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_4GEok2s3, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_sxFw4p9O, VIf(Bf5));
    __hv_varwrite_f(&sVarf_LRM9HkEV, VIf(Bf0));
    __hv_varwrite_f(&sVarf_3LPTPrnm, VIf(Bf6));
    __hv_line_f(&sLine_SXIYZcOU, VOf(Bf6));
    __hv_line_f(&sLine_CW4pAlgA, VOf(Bf0));
    __hv_line_f(&sLine_j83FWTJF, VOf(Bf5));
    __hv_line_f(&sLine_lW79zaPq, VOf(Bf8));
    __hv_line_f(&sLine_82MiiZWy, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_kfT5o06C, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_CFvQd8CY, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_RxHQYPWS, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_MGkfFXxB, VOf(Bf0));
    __hv_line_f(&sLine_hfJjCx0B, VOf(Bf6));
    __hv_line_f(&sLine_SF1XYWhJ, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_tJmKGh0Z, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_xdvl9hUn, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_hKv7R6RQ, VOf(Bf1));
    __hv_line_f(&sLine_UIaLReIg, VOf(Bf0));
    __hv_line_f(&sLine_VUl86IV5, VOf(Bf5));
    __hv_line_f(&sLine_pefKNPHT, VOf(Bf4));
    __hv_line_f(&sLine_M3uYUFF8, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_BJaeHudG, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_tRB4Txqn, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_oVGDfpux, VIf(Bf8));
    __hv_varwrite_f(&sVarf_HBdbFLjY, VIf(Bf6));
    __hv_varwrite_f(&sVarf_SUFj5CV9, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
